=================
django-analytical
=================

The django-analytical application integrates analytics services into a
Django_ project.

.. _Django: https://www.djangoproject.com/

:Package: https://pypi.python.org/pypi/django-analytical/
:Source:  https://github.com/jazzband/django-analytical


Overview
========

.. include:: ../README.rst
    :start-after: .. start docs include
    :end-before: .. end docs include

To get a feel of how django-analytical works, check out the
:doc:`tutorial`.


Contents
========

.. toctree::
    :maxdepth: 2

    tutorial
    install
    features
    services
    settings
    history
    license
